@@ -25,7 +25,7 @@ class ReadPipeDataTask : public QObject, public QRunnable
 {
     Q_OBJECT
 public:
-    explicit ReadPipeDataTask(ConnectionThread *connectionThread, DataControlOfferV1 *offerV1,
+    explicit ReadPipeDataTask( int pipeFds[2], DataControlOfferV1 *offerV1,
                               QString mimeType, QObject *parent = nullptr);
 
     void stopRunning();
@@ -40,14 +40,14 @@ private:
     bool readData(int fd, QByteArray &data);
 
 private:
+    int m_pipeFds[2];
     bool m_stopRunning;
     QString m_mimeType;
     QMutex m_mutexLock;
 
     DataControlOfferV1 *m_pOffer;
-    ConnectionThread *m_pConnectionThread;
 };
 
 
 #endif //READ_PIPE_DATA_TASK_H
-#endif // USE_DEEPIN_KF5_WAYLAND
\ No newline at end of file
+#endif // USE_DEEPIN_KF5_WAYLAND
